package de.intevation.flys.artifacts.model;

import de.intevation.artifactdatabase.state.Facet;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.flys.artifacts.FLYSArtifact;

import de.intevation.flys.artifacts.states.DefaultState.ComputeType;

import org.apache.log4j.Logger;

/**
 * Facet of a Waterlevel (WQKms).
 */
public class WaterlevelFacet extends DataFacet {

    private static Logger logger = Logger.getLogger(WaterlevelFacet.class);

    public WaterlevelFacet(int index, String name, String description) {
        super(index, name, description, ComputeType.ADVANCE, null, null);
    }

    public WaterlevelFacet(
        int         index,
        String      name,
        String      description,
        ComputeType type,
        String      stateID,
        String      hash
    ) {
        super(index, name, description, type, hash, stateID);
    }

    public WaterlevelFacet() {
    }

    protected WQKms [] getWQKms(CalculationResult res) {
        return (WQKms [])res.getData();
    }

    /**
     * Get waterlevel data.
     * @return a WQKms at given index.
     */
    public Object getData(Artifact artifact, CallContext context) {

        if (logger.isDebugEnabled()) {
            logger.debug("Get data for waterlevels at index: " + index +
                " /stateId: " + stateId);
        }

        FLYSArtifact winfo = (FLYSArtifact) artifact;

        CalculationResult res = (CalculationResult)
            winfo.compute(context, hash, stateId, type, false);

        if (res == null) {
            logger.error("WaterlevelFacet.getData: null result");
            return null;
        }

        if (winfo == null) {
            logger.error("WaterlevelFacet.getData: artifact is null");
            return null;
        }

        WQKms [] wqkms = getWQKms(res);

        return wqkms != null ? wqkms[index] : null;
    }


    /** Copy deeply. */
    @Override
    public Facet deepCopy() {
        WaterlevelFacet copy = new WaterlevelFacet();
        copy.set(this);
        copy.type    = type;
        copy.hash    = hash;
        copy.stateId = stateId;
        return copy;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
